@@ -89,7 +89,7 @@ def create_tfrecords_from_csv(data_dir, csv_path, outputfilename, IMAGE_SIZE = (
 
 	df.sort_values(['Image'], axis = 0, inplace = True)
 
-	addrs = glob.glob(DATA_DIR + '/*.jpg')
+	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
 	labels = list(df['Image'])
 
@@ -110,7 +110,7 @@ def create_split_tfrecords_from_csv(data_dir, csv, outfile1name, outfile2name, s
 
 	df.sort_values(['Image'], axis = 0, inplace = True)
 
-	addrs = glob.glob(DATA_DIR + '/*.jpg')
+	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
 	labels = list(df['Image'])
 
